'use strict';

(function() {
  window.addEventListener('load', init);
  const BUBBLE_NUM = 128;

  function init() {
    populateBubbles();
  }

  function populateBubbles() {
    let footerBubbles = id('bubbles');
    for (let i = 0; i < BUBBLE_NUM; i++) {
      console.log('new bubble');
      let newBubble = gen('div');
      setCSSVar(newBubble, 'size', 2, 6, 'rem');
      setCSSVar(newBubble, 'distance', 2, 6, 'rem');
      setCSSVar(newBubble, 'position', -5, 105, '%');
      setCSSVar(newBubble, 'time', 8, 12, 's');
      setCSSVar(newBubble, 'delay', -12, -8, 's');
      footerBubbles.appendChild(newBubble);
    }
  }

  function setCSSVar(element, varName, minVal, maxVal, unit) {
    let value = minVal + Math.random() * (maxVal - minVal);
    value = Math.round(value * 100) / 100.0;
    element.style.setProperty('--' + varName, value + unit);
  }

    /**
   * Returns the element that has the ID attribute with the specified value.
   * @param {string} idName - element ID
   * @returns {object} DOM object associated with id.
   */
    function id(idName) {
      return document.getElementById(idName);
    }

    /**
     * Returns the first element that matches the given CSS selector.
     * @param {string} selector - CSS query selector.
     * @returns {object} The first DOM object matching the query.
     */
    function qs(selector) {
      return document.querySelector(selector);
    }

    /**
     * Returns the array of elements that match the given CSS selector.
     * @param {string} selector - CSS query selector
     * @returns {object[]} array of DOM objects matching the query.
     */
    function qsa(selector) {
      return document.querySelectorAll(selector);
    }

    /**
     * Returns a new element with the given tag name.
     * @param {string} tagName - HTML tag name for new DOM element.
     * @returns {object} New DOM object for given HTML tag.
     */
    function gen(tagName) {
      return document.createElement(tagName);
    }
})();
