/**
 * This is model.js managing the behavior of model.js site specifically. It features two buttons
 *  that can switch the content of the page.
 */

'use strict';

(function() {
  window.addEventListener('load', init);

  function init() {
    let proBtn = id("protein-btn");
    let kinBtn = id("kinetic-btn");
    if (proBtn && kinBtn) { // if they both exist
      proBtn.addEventListener('click', revealProteins);
      kinBtn.addEventListener('click', revealKinetics);
    }
  }

  /**
   * reveals the kinetics modeling section and hides the protein modeling section.
   */
  function revealKinetics() {
    id("kinetic-modeling").classList.remove("concealed");
    id("protein-modeling").classList.add("concealed");
  }

  /**
   * reveals the protein modeling section and hides the kinetic modeling section.
   */
  function revealProteins() {
    id("kinetic-modeling").classList.add("concealed");
    id("protein-modeling").classList.remove("concealed");
  }

  /**
   * Returns the element that has the ID attribute with the specified value.
   * @param {string} idName - element ID
   * @returns {object} DOM object associated with id.
   */
  function id(idName) {
    return document.getElementById(idName);
  }
})();